@@ -8,7 +8,7 @@ Attean::Algebra - Representation of SPARQL algebra operators
 
 =head1 VERSION
 
-This document describes Attean::Algebra version 0.016
+This document describes Attean::Algebra version 0.018
 
 =head1 SYNOPSIS
 
@@ -26,7 +26,7 @@ in the Attean::Algebra namespace:
 
 use Attean::API::Query;
 
-package Attean::Algebra::Query 0.016 {
+package Attean::Algebra::Query 0.018 {
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
 	use Types::Standard qw(Bool ArrayRef HashRef ConsumerOf);
@@ -120,7 +120,7 @@ package Attean::Algebra::Query 0.016 {
 	}
 }
 
-package Attean::Algebra::Update 0.016 {
+package Attean::Algebra::Update 0.018 {
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
 	use Types::Standard qw(Bool);
@@ -142,7 +142,7 @@ package Attean::Algebra::Update 0.016 {
 
 =cut
 
-package Attean::Algebra::Sequence 0.016 {
+package Attean::Algebra::Sequence 0.018 {
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
 	use Moo;
@@ -150,6 +150,11 @@ package Attean::Algebra::Sequence 0.016 {
 
 	with 'Attean::API::UnionScopeVariables', 'Attean::API::Algebra', 'Attean::API::QueryTree';
 
+	sub arity {
+		my $self	= shift;
+		return scalar(@{ $self->children });
+	}
+	
 	sub algebra_as_string { return 'Sequence' }
 
 	sub sparql_tokens {
@@ -170,7 +175,7 @@ package Attean::Algebra::Sequence 0.016 {
 
 =cut
 
-package Attean::Algebra::Join 0.016 {
+package Attean::Algebra::Join 0.018 {
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
 	use Moo;
@@ -199,7 +204,7 @@ package Attean::Algebra::Join 0.016 {
 
 =cut
 
-package Attean::Algebra::LeftJoin 0.016 {
+package Attean::Algebra::LeftJoin 0.018 {
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
 	use Moo;
@@ -256,7 +261,7 @@ package Attean::Algebra::LeftJoin 0.016 {
 
 =cut
 
-package Attean::Algebra::Filter 0.016 {
+package Attean::Algebra::Filter 0.018 {
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
 	use Moo;
@@ -292,7 +297,7 @@ package Attean::Algebra::Filter 0.016 {
 
 =cut
 
-package Attean::Algebra::Union 0.016 {
+package Attean::Algebra::Union 0.018 {
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
 	use Moo;
@@ -323,7 +328,7 @@ package Attean::Algebra::Union 0.016 {
 
 =cut
 
-package Attean::Algebra::Graph 0.016 {
+package Attean::Algebra::Graph 0.018 {
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
 	use Moo;
@@ -371,7 +376,7 @@ package Attean::Algebra::Graph 0.016 {
 
 =cut
 
-package Attean::Algebra::Extend 0.016 {
+package Attean::Algebra::Extend 0.018 {
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
 	use Moo;
@@ -420,7 +425,7 @@ package Attean::Algebra::Extend 0.016 {
 
 =cut
 
-package Attean::Algebra::Minus 0.016 {
+package Attean::Algebra::Minus 0.018 {
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
 	use Moo;
@@ -458,7 +463,7 @@ package Attean::Algebra::Minus 0.016 {
 
 =cut
 
-package Attean::Algebra::Distinct 0.016 {
+package Attean::Algebra::Distinct 0.018 {
 	use Moo;
 	use namespace::clean;
 
@@ -472,7 +477,7 @@ package Attean::Algebra::Distinct 0.016 {
 
 =cut
 
-package Attean::Algebra::Reduced 0.016 {
+package Attean::Algebra::Reduced 0.018 {
 	use Moo;
 	use namespace::clean;
 
@@ -486,7 +491,7 @@ package Attean::Algebra::Reduced 0.016 {
 
 =cut
 
-package Attean::Algebra::Slice 0.016 {
+package Attean::Algebra::Slice 0.018 {
 	use Moo;
 	use Types::Standard qw(Int);
 	use namespace::clean;
@@ -509,7 +514,7 @@ package Attean::Algebra::Slice 0.016 {
 
 =cut
 
-package Attean::Algebra::Project 0.016 {
+package Attean::Algebra::Project 0.018 {
 	use Types::Standard qw(ArrayRef ConsumerOf);
 	use Moo;
 	use namespace::clean;
@@ -537,7 +542,7 @@ package Attean::Algebra::Project 0.016 {
 
 =cut
 
-package Attean::Algebra::Comparator 0.016 {
+package Attean::Algebra::Comparator 0.018 {
 	use Moo;
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
@@ -581,7 +586,7 @@ package Attean::Algebra::Comparator 0.016 {
 
 =cut
 
-package Attean::Algebra::OrderBy 0.016 {
+package Attean::Algebra::OrderBy 0.018 {
 	use Moo;
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
@@ -604,7 +609,7 @@ package Attean::Algebra::OrderBy 0.016 {
 
 =cut
 
-package Attean::Algebra::BGP 0.016 {
+package Attean::Algebra::BGP 0.018 {
 	use Moo;
 	use Attean::RDF;
 	use Set::Scalar;
@@ -674,7 +679,7 @@ package Attean::Algebra::BGP 0.016 {
 
 =cut
 
-package Attean::Algebra::Service 0.016 {
+package Attean::Algebra::Service 0.018 {
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
 	use Moo;
@@ -719,7 +724,7 @@ package Attean::Algebra::Service 0.016 {
 
 =cut
 
-package Attean::Algebra::Path 0.016 {
+package Attean::Algebra::Path 0.018 {
 	use Moo;
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
@@ -759,7 +764,7 @@ package Attean::Algebra::Path 0.016 {
 
 =cut
 
-package Attean::Algebra::Group 0.016 {
+package Attean::Algebra::Group 0.018 {
 	use utf8;
 	use Moo;
 	use Attean::API::Query;
@@ -829,7 +834,7 @@ package Attean::Algebra::Group 0.016 {
 
 =cut
 
-package Attean::Algebra::NegatedPropertySet 0.016 {
+package Attean::Algebra::NegatedPropertySet 0.018 {
 	use Moo;
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
@@ -874,7 +879,7 @@ package Attean::Algebra::NegatedPropertySet 0.016 {
 
 =cut
 
-package Attean::Algebra::PredicatePath 0.016 {
+package Attean::Algebra::PredicatePath 0.018 {
 	use Moo;
 	use Types::Standard qw(ConsumerOf);
 	use namespace::clean;
@@ -907,7 +912,7 @@ package Attean::Algebra::PredicatePath 0.016 {
 
 =cut
 
-package Attean::Algebra::InversePath 0.016 {
+package Attean::Algebra::InversePath 0.018 {
 	use Moo;
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
@@ -949,7 +954,7 @@ package Attean::Algebra::InversePath 0.016 {
 
 =cut
 
-package Attean::Algebra::SequencePath 0.016 {
+package Attean::Algebra::SequencePath 0.018 {
 	use Moo;
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
@@ -982,7 +987,7 @@ package Attean::Algebra::SequencePath 0.016 {
 
 =cut
 
-package Attean::Algebra::AlternativePath 0.016 {
+package Attean::Algebra::AlternativePath 0.018 {
 	use Moo;
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
@@ -1015,7 +1020,7 @@ package Attean::Algebra::AlternativePath 0.016 {
 
 =cut
 
-package Attean::Algebra::ZeroOrMorePath 0.016 {
+package Attean::Algebra::ZeroOrMorePath 0.018 {
 	use Moo;
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
@@ -1056,7 +1061,7 @@ package Attean::Algebra::ZeroOrMorePath 0.016 {
 
 =cut
 
-package Attean::Algebra::OneOrMorePath 0.016 {
+package Attean::Algebra::OneOrMorePath 0.018 {
 	use Moo;
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
@@ -1097,7 +1102,7 @@ package Attean::Algebra::OneOrMorePath 0.016 {
 
 =cut
 
-package Attean::Algebra::ZeroOrOnePath 0.016 {
+package Attean::Algebra::ZeroOrOnePath 0.018 {
 	use Moo;
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
@@ -1138,7 +1143,7 @@ package Attean::Algebra::ZeroOrOnePath 0.016 {
 
 =cut
 
-package Attean::Algebra::Table 0.016 {
+package Attean::Algebra::Table 0.018 {
 	use Moo;
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
@@ -1192,7 +1197,7 @@ package Attean::Algebra::Table 0.016 {
 
 =cut
 
-package Attean::Algebra::Ask 0.016 {
+package Attean::Algebra::Ask 0.018 {
 	use Moo;
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
@@ -1210,7 +1215,7 @@ package Attean::Algebra::Ask 0.016 {
 
 =cut
 
-package Attean::Algebra::Construct 0.016 {
+package Attean::Algebra::Construct 0.018 {
 	use Moo;
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
@@ -1224,14 +1229,18 @@ package Attean::Algebra::Construct 0.016 {
 
 	sub in_scope_variables { return qw(subject predicate object); }
 	sub tree_attributes { return; }
-	sub algebra_as_string { return 'Construct' }
+	sub algebra_as_string {
+		my $self	= shift;
+		my $triples	= $self->triples;
+		return sprintf('Construct { %s }', join(' . ', map { $_->as_string } @$triples));
+	}
 }
 
 =item * L<Attean::Algebra::Describe>
 
 =cut
 
-package Attean::Algebra::Describe 0.016 {
+package Attean::Algebra::Describe 0.018 {
 	use Moo;
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
@@ -1252,7 +1261,7 @@ package Attean::Algebra::Describe 0.016 {
 
 =cut
 
-package Attean::Algebra::Load 0.016 {
+package Attean::Algebra::Load 0.018 {
 	use Moo;
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
@@ -1295,7 +1304,7 @@ package Attean::Algebra::Load 0.016 {
 
 =cut
 
-package Attean::Algebra::Clear 0.016 {
+package Attean::Algebra::Clear 0.018 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use AtteanX::SPARQL::Constants;
@@ -1349,7 +1358,7 @@ package Attean::Algebra::Clear 0.016 {
 
 =cut
 
-package Attean::Algebra::Create 0.016 {
+package Attean::Algebra::Create 0.018 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use AtteanX::SPARQL::Constants;
@@ -1384,7 +1393,7 @@ package Attean::Algebra::Create 0.016 {
 
 =cut
 
-package Attean::Algebra::Add 0.016 {
+package Attean::Algebra::Add 0.018 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use AtteanX::SPARQL::Constants;
@@ -1442,7 +1451,7 @@ package Attean::Algebra::Add 0.016 {
 
 =cut
 
-package Attean::Algebra::Modify 0.016 {
+package Attean::Algebra::Modify 0.018 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use AtteanX::SPARQL::Constants;
@@ -1629,7 +1638,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2016 Gregory Todd Williams.
+Copyright (c) 2014--2018 Gregory Todd Williams.
 This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
