@@ -10,7 +10,7 @@ AtteanX::Parser::Turtle - Turtle RDF Parser
 
 =head1 VERSION
 
-This document describes AtteanX::Parser::Turtle version 0.016
+This document describes AtteanX::Parser::Turtle version 0.018
 
 =head1 SYNOPSIS
 
@@ -44,10 +44,11 @@ A boolean indicating whether term values should be canonicalized during parsing.
 
 =cut
 
-package AtteanX::Parser::Turtle 0.016 {
+package AtteanX::Parser::Turtle 0.018 {
 	use Moo;
 	use Types::Standard qw(Bool ArrayRef HashRef Str Maybe InstanceOf);
 	use utf8;
+	use Carp qw(carp);
 	use Encode qw(encode);
 	use Scalar::Util qw(blessed);
 	use AtteanX::Parser::Turtle::Constants;
@@ -142,12 +143,15 @@ serialization is found at the beginning of C<< $bytes >>.
 =cut
 
 	sub parse_term_from_string {
-# 		TODO: warn "parse_term_from_string is now called parse_term_from_bytes\n";
+		carp "parse_term_from_string is deprecated and will be removed in Attean 0.018 (use parse_term_from_bytes instead)";
 		return shift->parse_term_from_bytes(@_);
 	}
 	
 	sub parse_term_from_bytes {
 		my $self	= shift;
+		unless (ref($self)) {
+			$self	= $self->new();
+		}
 		return $self->parse_node(@_);
 	}
 	
@@ -585,7 +589,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2016 Gregory Todd Williams. This
+Copyright (c) 2014--2018 Gregory Todd Williams. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
